@@ -1,12 +1,11 @@
 package DBIx::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use DBI;
 use Carp;
 use Spreadsheet::HTML;
-use Data::Dumper;
 
 sub connect {
     my $class = shift;
@@ -24,7 +23,7 @@ sub connect {
         $self->{keep_alive} = 1;
     } else {
         # create my own db handle
-        eval { $self->{dbh} = DBI->connect(@_) };
+        eval { $self->{dbh} = DBI->connect( @_ ) };
         carp $@ and return undef if $@;
     }
 
@@ -48,14 +47,17 @@ sub do {
     return $self;
 }
 
-sub generate {
+sub generate    { _generator( shift )->generate( @_ )  }
+sub portrait    { _generator( shift )->generate( @_ )  }
+sub transpose   { _generator( shift )->transpose( @_ ) }
+sub landscape   { _generator( shift )->transpose( @_ ) }
+sub reverse     { _generator( shift )->reverse( @_ )   }
+
+sub _generator  {
     my $self = shift;
-    my %attrs = @_;
-    return Spreadsheet::HTML
-        ->new( data => [ $self->{head}, @{ $self->{rows} } ] )
-        ->generate( { %attrs} )
-    ;
-}
+    return Spreadsheet::HTML->new( data => [ $self->{head}, @{ $self->{rows} } ] );
+ }
+
 
 # disconnect database handle if i created it
 sub DESTROY {
@@ -72,44 +74,73 @@ __END__
 
 DBIx::HTML - SQL queries to HTML tables.
 
+=head1 THIS IS AN ALPHA RELEASE.
+
+While most functionality for this module has been completed,
+testing has not. This module has a strong dependency on
+L<Spreadsheet::HTML> which currently is also an alpha release.
+
+You are encouraged to try my older L<DBIx::XHTML_Table> during
+the development of this module.
+
 =head1 USAGE
 
     use DBIx::HTML;
 
-    # database credentials - fill in the blanks
-    my @creds = ( $data_source, $usr, $pass );
-    my $table = DBIx::HTML->connect( @creds )
-
-    $table->do('
-        select foo from bar
-        where baz = ?
-        order by foo
-    ', [ 'qux' ]);
-
-    print $table->generate( table => { border => 1 } );
+    my $table = DBIx::HTML->connect( @db_credentials );
+    $table->do( $query );
+    print $table->generate;
 
     # stackable method calls:
     print DBIx::HTML
-        ->connect( @creds )
+        ->connect( @db_credentials )
         ->do( 'select foo,baz from bar' )
-        ->generate( table => { border => 1 } )
+        ->generate
     ;
 
 =head1 METHODS
 
 =over 4
 
-=item connect()
+=item connect( @database_credentials )
 
 Connects to the database. See L<DBI> for how to do that.
+Optionally, create your own database handle and pass it:
 
-=item do()
+  my $dbh = DBI->connect ( @db_creds );
+  my $table = DBIx::HTML->connect( $dbh );
 
-Executes the query.
+  # do stuff and then finally ...
+  $dbh->disconnect;
 
-=item generate()
+DBIx::HTML will not disconnect your database handle.
 
-Produce and return the HTML table.
+=item do( $sql_query )
+
+Executes the query, fetches the results and stores
+them internally.
+
+=item portrait( key => 'value' )
+
+=item generate( key => 'value' )
+
+Produce and return the HTML table with headers at top.
+
+(See L<Spreadsheet::HTML> for available function arguments.)
+
+=item landscape( key => 'value' )
+
+=item transpose( key => 'value' )
+
+Produce and return the HTML table with headers at left.
+
+(See L<Spreadsheet::HTML> for available function arguments.)
+
+=item reverse( key => 'value' )
+
+Produce and return the HTML table with headers at bottom.
+
+(See L<Spreadsheet::HTML> for available function arguments.)
 
 =back
 
@@ -176,6 +207,18 @@ L<http://search.cpan.org/dist/DBIx-HTML/>
 
 =back
 
+=head1 ACKNOWLEDGEMENTS
+
+Thank you very much! :)
+
+=over 4
+
+=item * Neil Bowers
+
+Helped with Makefile.PL suggestions and corrections.
+
+=back
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Jeff Anderson.
